/*
 * Copyright (c) 2012 ICM Uniwersytet Warszawski All rights reserved.
 * See LICENCE.txt file for licensing information.
 */
package eu.unicore.gateway;

import java.io.File;
import java.net.URI;
import java.net.URL;

import org.apache.commons.httpclient.HttpClient;
import org.apache.commons.httpclient.HttpStatus;
import org.apache.commons.httpclient.methods.ByteArrayRequestEntity;
import org.apache.commons.httpclient.methods.PostMethod;
import org.apache.commons.httpclient.methods.RequestEntity;

import eu.unicore.gateway.client.HttpClientFactory;

import junit.framework.TestCase;

public class TestHttpsServer extends TestCase {
	protected Gateway gw;
	protected FakeHttpsServer backend;
	
	@Override
	protected void setUp() throws Exception {
		File gp = new File("src/test/resources/gateway.properties");
		File sp = new File("src/test/resources/security.properties");
		File cp = new File("src/test/resources/connection.properties");
		gw = new Gateway(gp, cp, sp);
		gw.startGateway();
		backend = FakeHttpsServer.getInstance();
		backend.start();
	}
	
	@Override
	protected void tearDown()throws Exception{
		Thread.sleep(1000);
		backend.stop();
		gw.stopGateway();
	}

	public void testWithSSL() {
		String url="https://localhost:65437/service";
		try{
			HttpClient hc = gw.getClientFactory().makeHttpClient(new URL(url));
			PostMethod post= prepareForwardedPOST(new URI(url), 
					new ByteArrayRequestEntity(TestServer.getBody(url)), gw.getClientFactory());

			hc.executeMethod(post);
			System.out.println(post.getStatusLine());
			String resp = post.getResponseBodyAsString();
			System.out.println(resp);
			int status=post.getStatusCode();
			assertEquals(HttpStatus.SC_OK, status);
			assertFalse(resp.contains("Fault"));
			assertTrue(resp.contains("OKOKOK"));
		} catch(Exception ex){
			ex.printStackTrace();
			fail();
		}
	}
	
	private PostMethod prepareForwardedPOST(URI uri, RequestEntity reqEntity, 
			HttpClientFactory clientFactory) throws Exception {
		StringBuilder path=new StringBuilder(uri.getPath());
		if(uri.getQuery()!=null){
			path.append("?");
			path.append(uri.getQuery());
		}
		PostMethod post = clientFactory.makePostMethod(
				path.toString(), reqEntity);

		return post;
	}

}
